Geometry
========
takes care of creating artificial geometry and computation of geometry (sensitivity/contribution) matrices with single line of sight approximation.

Geometry matrix
---------------

.. automodule :: tomotok.core.geometry.generators
    :members:
    :undoc-members:
    :noindex:

Reconstruction grid
-------------------

.. autoclass :: tomotok.core.geometry.RegularGrid
    :members:
    :noindex:


Lines of sight
--------------

.. automodule :: tomotok.core.geometry.los
    :members:
    :noindex: